@@ -1,7 +1,5 @@
 #!/bin/sh
 
-export LC_ALL=C.UTF-8
-export LANG=C.UTF-8
 export BIN_DIR=`dirname $0`
 export PROJECT_ROOT="${BIN_DIR}/.."
 . "${PROJECT_ROOT}/name.py"
@@ -9,6 +7,7 @@ export VIRTUALENV=${VIRTUALENV:="${app_name}back"}
 export FLASK_ENV=${FLASK_ENV:="production"}
 export PY_VERSION=${PY_VERSION:="3.7"}
 export SYSPKG=${SYSPKG:="no"}
+export DBTYPE=${DBTYPE:="sql"}
 
 
 setup() {
@@ -24,7 +23,7 @@ setup() {
     if [ "${update}" != "no" ]; then
       pip install -U pip
       pip install -U wheel
-      pip install -U --upgrade-strategy eager -r requirements.txt
+      pip install -U --upgrade-strategy eager -e ".[${DBTYPE}]"
     fi
   fi
 }
